Crate bb_geometry

Geometry

Geometry is a small crate for myself, which provides some limited functionality for vectors and rotations in four-dimensional Euclidean space.

Copyright (C) 2025 Benjamin Bahr

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see https://www.gnu.org/licenses/.

Modules

rotation3d
This is the module covering anything related to rotations in 3d. So far this is quite limited in scope.
rotation4d
This is the module covering anything related to rotations in 4d. So far this is quite limited in scope.
vector3d
vector4d

Constants

ALMOST_ZERO